# babel-plugin-smart-import
This plugin is used to import on demand.

## Install
```
npm install -D babel-plugin-smart-import
```

## Usage
### Use for antd
babel.config.js
```js
var plugins = [
    ['babel-plugin-smart-import', {
        library: 'antd',
        directory: 'lib',           
        namingRule: 'dash',         // use ant/lib/xxx-xxx folder
        style: {                    
            directory: 'style',     
            namingRule: 'index',    // use ant/lib/xxx/style/index file
            ext: 'css'              // js, css or less all fine.
        }
    }]
];
```
app.jsx
```js
import { Button } from 'antd';
ReactDOM.render(<Button>xxxx</Button>);
                ↓
var _button = require('antd/lib/button');
ReactDOM.render(<_button>xxxx</_button>);
```
### Use for @material-ui/core
babel.config.js
```js
var plugins = [
    ['babel-plugin-smart-import', {
        library: '@material-ui/core'
    }]
];
```
app.jsx
```js
import { Button } from '@material-ui/core';
ReactDOM.render(<Button>xxxx</Button>);
                ↓
var _button = require('@material-ui/core/Button');
ReactDOM.render(<_button>xxxx</_button>);
```
### Use for elementalui
babel.config.js
```js
var plugins = [
    ['babel-plugin-smart-import', {
        library: 'elemental',
        directory: 'lib/components',
        style: {
            directory: '/less/components',  // root with '/' is required
            namingRule: 'big-camel',
            ext: 'less'
        }
    }]
];
```
app.jsx
```js
import { Button } from 'elemental';
ReactDOM.render(<Button>xxxx</Button>);
                ↓
var _button = require('elemental/lib/components/Button');
require('elemental/less/components/Button');
ReactDOM.render(<_button>xxxx</_button>);
```

## Options
```js
{
    library,             // string, required
    directory,           // string
    namingRule,          // string | function, 'little-camel', 'big-camel', 'dash', 'underline', function, default to 'big-camel'.
    importDefault,       // boolean 
    style: {             // boolean | object, default to false.
        directory,       // string, 'style' or '/less/component', default to upper directory.
        namingRule,      // string, 'little-camel', 'big-camel', 'dash', 'underline', custom string, function, default to null.
        ext              // string, js, css, less, sass, default to null.
    }
}
```
### library
string, default to null.  
Set library name.
### directory
string, default to 'lib'.  
Set component directory. 
### namingRule
'little-camel', 'big-camel', 'dash', 'underline' or function, default to 'big-camel'.
### importDefault
boolean, default to true.
Transform import type to default.
### style
boolean or object, default to false.
import related style file and set import mode with style.
#### directory
string, default to component directory.
Set style directory. 
#### namingRule
'little-camel', 'big-camel', 'dash', 'underline', custom string name or function, default to null.
#### ext
string, default to null.
style file extension, example 'css', 'less', 'sass' or 'js'.